# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/01_ctyp.ipynb.

# %% auto 0
__all__ = ['ClsInt', 'ClsStr', 'ClsBool', 'ClsFloat']

# %% ../nbs/01_ctyp.ipynb 4
from typing import (
    Type, TypeAlias, ClassVar, 
)

# %% ../nbs/01_ctyp.ipynb 6
ClsInt: TypeAlias = ClassVar[int]
ClsStr: TypeAlias = ClassVar[str]
ClsBool: TypeAlias = ClassVar[bool]
ClsFloat: TypeAlias = ClassVar[float]
